from setuptools import find_packages, setup

setup(
    name='PlotLinearSolverResult',
    packages=find_packages(),
    version='0.1.0',
    description='This project is for plot LinearMSTMM solver result that is write with hdf5.',
    author='Zhengquan Liu',
    license='MIT',
)
